@@ -9,7 +9,7 @@ import collections
 from copy import copy
 import csv
 import itertools
-import math
+from functools import wraps
 import random
 from statistics import mean
 from typing import Iterator, List, Tuple, Callable
@@ -17,8 +17,7 @@ from typing import Iterator, List, Tuple, Callable
 import toolz
 from toolz import curry
 
-from leap_ec.core import Individual
-from leap_ec import util
+from leap_ec.individual import Individual
 
 
 ##############################
@@ -73,6 +72,7 @@ def iteriter_op(f):
 
     :param f function: the function to wrap
     """
+    @wraps(f)
     def typecheck_f(next_individual: Iterator, *args, **kwargs) -> Iterator:
         if not isinstance(next_individual, collections.abc.Iterator):
             raise ValueError(
@@ -103,6 +103,7 @@ def listlist_op(f):
 
     :param f function: the function to wrap
     """
+    @wraps(f)
     def typecheck_f(population: List, *args, **kwargs) -> List:
         if not isinstance(population, list):
             raise ValueError(
@@ -133,6 +134,7 @@ def listiter_op(f):
 
     :param f function: the function to wrap
     """
+    @wraps(f)
     def typecheck_f(population: List, *args, **kwargs) -> Iterator:
         if not isinstance(population, list):
             raise ValueError(
@@ -163,6 +165,7 @@ def iterlist_op(f):
 
     :param f function: the function to wrap
     """
+    @wraps(f)
     def typecheck_f(next_individual: Iterator, *args, **kwargs) -> List:
         if not isinstance(next_individual, collections.abc.Iterator):
             raise ValueError(
@@ -189,11 +192,13 @@ def iterlist_op(f):
 def evaluate(next_individual: Iterator) -> Iterator:
     """ Evaluate and returns the next individual in the pipeline
 
-    >>> from leap_ec import core, binary_problems
+    >>> from leap_ec.individual import Individual
+    >>> from leap_ec.decoder import IdentityDecoder
+    >>> from leap_ec.binary_rep.problems import MaxOnes
 
     We need to specify the decoder and problem so that evaluation is possible.
 
-    >>> ind = core.Individual([1,1], decoder=core.IdentityDecoder(), problem=binary_problems.MaxOnes())
+    >>> ind = Individual([1,1], decoder=IdentityDecoder(), problem=MaxOnes())
 
     >>> evaluated_ind = next(evaluate(iter([ind])))
 
@@ -225,7 +230,7 @@ def const_evaluate(population: List, value) -> List:
 
     This is useful for algorithms that need to assign an arbitrary initial
     fitness value before using their normal evaluation method.  Some forms of
-    cooperative coevolution are an eample.
+    cooperative coevolution are an example.
     """
     for ind in population:
         ind.fitness = value
@@ -241,7 +246,7 @@ def const_evaluate(population: List, value) -> List:
 def clone(next_individual: Iterator) -> Iterator:
     """ clones and returns the next individual in the pipeline
 
-    >>> from leap_ec import core
+    >>> from leap_ec.individual import Individual
 
     Create a common decoder and problem for individuals.
 
@@ -259,45 +264,6 @@ def clone(next_individual: Iterator) -> Iterator:
         yield individual.clone()
 
 
-##############################
-# Function mutate_bitflip
-##############################
-@curry
-@iteriter_op
-def mutate_bitflip(next_individual: Iterator, expected: float = 1) -> Iterator:
-    """ mutate and return an individual with a binary representation
-
-    >>> from leap_ec import core, binary_problems
-
-    >>> original = Individual([1,1])
-
-    >>> mutated = next(mutate_bitflip(iter([original])))
-
-    :param individual: to be mutated
-    :param expected: the *expected* number of mutations, on average
-    :return: mutated individual
-    """
-    def flip(gene):
-        if random.random() < probability:
-            return (gene + 1) % 2
-        else:
-            return gene
-
-    while True:
-        individual = next(next_individual)
-
-        # Given the average expected number of mutations, calculate the
-        # probability for flipping each bit.  This calculation must be made
-        # each time given that we may be dealing with dynamic lengths.
-        probability = compute_expected_probability(expected, individual.genome)
-
-        individual.genome = [flip(gene) for gene in individual.genome]
-
-        individual.fitness = None  # invalidate fitness since we have new genome
-
-        yield individual
-
-
 ##############################
 # Function uniform_crossover
 ##############################
@@ -308,7 +274,8 @@ def uniform_crossover(next_individual: Iterator,
     """ Generator for recombining two individuals and passing them down the
     line.
 
-    >>> from leap_ec import core, binary_problems
+    >>> from leap_ec.individual import Individual
+    >>> from leap_ec.ops import uniform_crossover
 
     >>> first = Individual([0,0])
     >>> second = Individual([1,1])
@@ -369,7 +336,8 @@ def n_ary_crossover(next_individual: Iterator,
 
     We also assume that the passed in individuals are *clones* of parents.
 
-    >>> from leap_ec import core, binary_problems
+    >>> from leap_ec.individual import Individual
+    >>> from leap_ec.ops import n_ary_crossover
 
     >>> first = Individual([0,0])
     >>> second = Individual([1,1])
@@ -435,87 +403,33 @@ def n_ary_crossover(next_individual: Iterator,
         yield child2
 
 
-##############################
-# Function mutate_gaussian
-##############################
-def mutate_gaussian(std: float, expected: float = None,
-                    hard_bounds: Tuple[float, float] = (-math.inf, math.inf)):
-    """ mutate and return an individual with a real-valued representation
-
-    TODO hard_bounds should also be able to take a sequence —Siggy
-
-    :param next_individual: to be mutated
-
-    :param std: standard deviation to be equally applied to all individuals;
-        this can be a scalar value or a "shadow vector" of standard deviations
-
-    :param expected: the *expected* number of mutations per individual,
-        on average.  If None, all genes will be mutated.
-
-    :param hard_bounds: to clip for mutations; defaults to (- ∞, ∞)
-    :return: a generator of mutated individuals.
-    """
-    def add_gauss(x, std, probability):
-        if random.random() < probability:
-            return random.gauss(x, std)
-        else:
-            return x
-
-    def clip(x):
-        return max(hard_bounds[0], min(hard_bounds[1], x))
-
-    def mutate(next_individual: Iterator) -> Iterator:
-        while True:
-            individual = next(next_individual)
-
-            # compute actual probability of mutation based on expected number of
-            # mutations and the genome length
-            if expected is None:
-                p = 1.0
-            else:
-                p = compute_expected_probability(expected, individual.genome)
-
-            if util.is_sequence(std):
-                # We're given a vector of "shadow standard deviations" so apply
-                # each sigma individually to each gene
-                individual.genome = [
-                    clip(
-                        add_gauss(
-                            x, s, p)) for x, s in zip(
-                        individual.genome, std)]
-            else:
-                individual.genome = [clip(add_gauss(x, std, p))
-                                     for x in individual.genome]
-            # invalidate fitness since we have new genome
-            individual.fitness = None
-
-            yield individual
-
-    return mutate
-
 
 ##############################
-# Function truncate
+# Function truncation_selection
 ##############################
 @curry
 @listlist_op
-def truncate(offspring: List, size: int, parents: List = None) -> List:
+def truncation_selection(offspring: List, size: int, parents: List = None) -> List:
     """ return the `size` best individuals from the given population
 
         This defaults to (mu, lambda) if `parents` is not given.
 
-        >>> from leap_ec import core, ops, binary_problems
-        >>> pop = [core.Individual([0, 0, 0], decoder=core.IdentityDecoder(), problem=binary_problems.MaxOnes()),
-        ...        core.Individual([0, 0, 1], decoder=core.IdentityDecoder(), problem=binary_problems.MaxOnes()),
-        ...        core.Individual([1, 1, 0], decoder=core.IdentityDecoder(), problem=binary_problems.MaxOnes()),
-        ...        core.Individual([1, 1, 1], decoder=core.IdentityDecoder(), problem=binary_problems.MaxOnes())]
+        >>> from leap_ec.individual import Individual
+        >>> from leap_ec.decoder import IdentityDecoder
+        >>> from leap_ec.binary_rep.problems import MaxOnes
+        >>> from leap_ec.ops import truncation_selection
+
+        >>> pop = [Individual([0, 0, 0], decoder=IdentityDecoder(), problem=MaxOnes()),
+        ...        Individual([0, 0, 1], decoder=IdentityDecoder(), problem=MaxOnes()),
+        ...        Individual([1, 1, 0], decoder=IdentityDecoder(), problem=MaxOnes()),
+        ...        Individual([1, 1, 1], decoder=IdentityDecoder(), problem=MaxOnes())]
 
         We need to evaluate them to get their fitness to sort them for
         truncation.
 
-        >>> pop = core.Individual.evaluate_population(pop)
+        >>> pop = Individual.evaluate_population(pop)
 
-        >>> truncated = truncate(pop, 2)
+        >>> truncated = truncation_selection(pop, 2)
 
         TODO Do we want an optional context to over-ride the 'parents' parameter?
 
@@ -533,24 +447,28 @@ def truncate(offspring: List, size: int, parents: List = None) -> List:
 
 
 ##############################
-# Function tournament
+# Function tournament_selection
 ##############################
 @curry
 @listiter_op
-def tournament(population: List, k: int = 2) -> Iterator:
+def tournament_selection(population: List, k: int = 2) -> Iterator:
     """ Selects the best individual from k individuals randomly selected from
         the given population
 
-        >>> from leap_ec import core, ops, binary_problems
-        >>> pop = [core.Individual([0, 0, 0], decoder=core.IdentityDecoder(), problem=binary_problems.MaxOnes()),
-        ...        core.Individual([0, 0, 1], decoder=core.IdentityDecoder(), problem=binary_problems.MaxOnes())]
+        >>> from leap_ec.individual import Individual
+        >>> from leap_ec.decoder import IdentityDecoder
+        >>> from leap_ec.binary_rep.problems import MaxOnes
+        >>> from leap_ec.ops import tournament_selection
+
+        >>> pop = [Individual([0, 0, 0], IdentityDecoder(), problem=MaxOnes()),
+        ...        Individual([0, 0, 1], IdentityDecoder(), problem=MaxOnes())]
 
         We need to evaluate them to get their fitness to sort them for
         truncation.
 
-        >>> pop = core.Individual.evaluate_population(pop)
+        >>> pop = Individual.evaluate_population(pop)
 
-        >>> best = tournament(pop)
+        >>> best = tournament_selection(pop)
 
         :param population: from which to select
 
@@ -609,12 +527,13 @@ def naive_cyclic_selection(population: List) -> Iterator:
     This is "naive" because it doesn't shuffle the population between complete
     tours to minimize bias.
 
-    >>> from leap_ec import core, ops
+    >>> from leap_ec.individual import Individual
+    >>> from leap_ec.ops import naive_cyclic_selection
 
-    >>> pop = [core.Individual([0, 0]),
-    ...        core.Individual([0, 1])]
+    >>> pop = [Individual([0, 0]),
+    ...        Individual([0, 1])]
 
-    >>> cyclic_selector = ops.naive_cyclic_selection(pop)
+    >>> cyclic_selector = naive_cyclic_selection(pop)
 
     :param population: from which to select
     :return: the next selected individual
@@ -635,12 +554,13 @@ def cyclic_selection(population: List) -> Iterator:
     sequence, returns the individuals in that new order, and repeats this
     process.
 
-    >>> from leap_ec import core, ops
+    >>> from leap_ec.individual import Individual
+    >>> from leap_ec.ops import cyclic_selection
 
-    >>> pop = [core.Individual([0, 0]),
-    ...        core.Individual([0, 1])]
+    >>> pop = [Individual([0, 0]),
+    ...        Individual([0, 1])]
 
-    >>> cyclic_selector = ops.cyclic_selection(pop)
+    >>> cyclic_selector = cyclic_selection(pop)
 
     :param population: from which to select
     :return: the next selected individual
@@ -686,14 +606,15 @@ def pool(next_individual: Iterator, size: int) -> List:
     selection and birth operators, but could also be used to, say, "pool"
     individuals to be passed to an EDA as a training set.
 
-    >>> from leap_ec import core, ops
+    >>> from leap_ec.individual import Individual
+    >>> from leap_ec.ops import naive_cyclic_selection
 
-    >>> pop = [core.Individual([0, 0]),
-    ...        core.Individual([0, 1])]
+    >>> pop = [Individual([0, 0]),
+    ...        Individual([0, 1])]
 
-    >>> cyclic_selector = ops.naive_cyclic_selection(pop)
+    >>> cyclic_selector = naive_cyclic_selection(pop)
 
-    >>> pool = ops.pool(cyclic_selector, 3)
+    >>> pool = pool(cyclic_selector, 3)
 
     print(pool)
     [Individual([0, 0], None, None), Individual([0, 1], None, None), Individual([0, 0], None, None)]
@@ -872,10 +793,10 @@ class CooperativeEvaluate(Operator):
 
 
 ##############################
-# Helper Functions
+# function compute_expected_probability
 ##############################
-def compute_expected_probability(
-        expected: float, individual_genome: List) -> float:
+def compute_expected_probability(expected: float, individual_genome: List) \
+        -> float:
     """ Computed the probability of mutation based on the desired average
     expected mutation and genome length.
 
